==> websafe_svg-1.1.0.tar.gz: example/lib/src/network_svg_page.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:websafe_svg/websafe_svg.dart';
import 'package:websafe_svg_example/src/svg_page.dart';

class NetworkSvgPage extends StatefulWidget {
  NetworkSvgPage({
    Key key,
  }) : super(key: key);

  @override
  _NetworkSvgPageState createState() => _NetworkSvgPageState();
}

class _NetworkSvgPageState extends State<NetworkSvgPage> {
  List<String> _svgs;

  @override
  void initState() {
    super.initState();

    _initialize();
  }

  Future<void> _initialize() async {
    var data = await rootBundle.loadString('assets/all.json');
    var all = json.decode(data);

    var svgs = <String>[];
    for (var i in all) {
      svgs.add(i?.toString());
    }
    _svgs = svgs;

    if (mounted == true) {
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Network'),
      ),
      body: _svgs == null
          ? Center(
              child: CircularProgressIndicator(),
            )
          : ListView.builder(
              itemCount: _svgs.length,
              itemBuilder: (BuildContext context, int index) => Padding(
                padding: EdgeInsets.only(bottom: 8.0),
                child: ListTile(
                  leading: Material(
                    borderRadius: BorderRadius.circular(30.0),
                    color: Color(0xffa0a0a0),
                    elevation: 2.0,
                    child: Container(
                      alignment: Alignment.center,
                      height: 60.0,
                      width: 60.0,
                      child: InkWell(
                        onTap: () => Navigator.of(context).push(
                          MaterialPageRoute(
                            builder: (BuildContext context) => SvgPage(
                              child: WebsafeSvg.network(
                                'https://raw.githubusercontent.com/peiffer-innovations/websafe_svg/master/example/assets-src/svgs/${_svgs[index]}',
                                fit: BoxFit.contain,
                                height: 30.0,
                                width: 30.0,
                              ),
                            ),
                          ),
                        ),
                        child: WebsafeSvg.network(
                          'https://raw.githubusercontent.com/peiffer-innovations/websafe_svg/master/example/assets-src/svgs/${_svgs[index]}',
                          color: Colors.white,
                          fit: BoxFit.contain,
                          height: 30.0,
                          width: 30.0,
                        ),
                      ),
                    ),
                  ),
                  title: Text(_svgs[index]),
                ),
              ),
            ),
    );
  }
}

==> websafe_svg-2.1.0.tar.gz: example/lib/src/network_svg_page.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:websafe_svg/websafe_svg.dart';
import 'package:websafe_svg_example/src/svg_page.dart';

class NetworkSvgPage extends StatefulWidget {
  NetworkSvgPage({
    Key key,
  }) : super(key: key);

  @override
  _NetworkSvgPageState createState() => _NetworkSvgPageState();
}

class _NetworkSvgPageState extends State<NetworkSvgPage> {
  List<String> _svgs;

  @override
  void initState() {
    super.initState();

    _initialize();
  }

  Future<void> _initialize() async {
    var data = await rootBundle.loadString('assets/all.json');
    var all = json.decode(data);

    var svgs = <String>[];
    for (var i in all) {
      svgs.add(i?.toString());
    }
    _svgs = svgs;

    if (mounted == true) {
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Network'),
      ),
      body: _svgs == null
          ? Center(
              child: CircularProgressIndicator(),
            )
          : ListView.builder(
              itemCount: _svgs.length,
              itemBuilder: (BuildContext context, int index) => Padding(
                padding: EdgeInsets.only(bottom: 8.0),
                child: ListTile(
                  leading: Material(
                    borderRadius: BorderRadius.circular(30.0),
                    color: Color(0xffa0a0a0),
                    elevation: 2.0,
                    child: Container(
                      alignment: Alignment.center,
                      height: 60.0,
                      width: 60.0,
                      child: InkWell(
                        onTap: () => Navigator.of(context).push(
                          MaterialPageRoute(
                            builder: (BuildContext context) => SvgPage(
                              child: WebsafeSvg.network(
                                'https://raw.githubusercontent.com/peiffer-innovations/websafe_svg/main/example/assets-src/svgs/${_svgs[index]}',
                                fit: BoxFit.contain,
                                height: 30.0,
                                width: 30.0,
                              ),
                            ),
                          ),
                        ),
                        child: WebsafeSvg.network(
                          'https://raw.githubusercontent.com/peiffer-innovations/websafe_svg/main/example/assets-src/svgs/${_svgs[index]}',
                          color: Colors.white,
                          fit: BoxFit.contain,
                          height: 30.0,
                          width: 30.0,
                        ),
                      ),
                    ),
                  ),
                  title: Text(_svgs[index]),
                ),
              ),
            ),
    );
  }
}
